@@ -2,42 +2,37 @@
 #' @param spin_params spin system definition.
 #' @param ft transmitter frequency in Hz.
 #' @param ref reference value for ppm scale.
+#' @param nuc acquisition nucleus.
+#' @param acq_delay delay between excitation and acquisition.
 #' @return list of resonance amplitudes and frequencies.
 #' @export
-seq_pulse_acquire <- function(spin_params, ft, ref) {
+seq_pulse_acquire <- function(spin_params, ft, ref, nuc = "1H",
+                              acq_delay = 0) {
+  
   sys <- spin_sys(spin_params, ft, ref)
   
-  sys$rho <- gen_F(sys, "z")
+  sys$rho <- gen_F(sys, "z", nuc)
    
   angle <- 90
-  Fx <- gen_F(sys, "x", "1H")
+  Fx <- gen_F(sys, "x",  nuc)
   lhs_pulse <- matexp(-Fx * 1i * angle * pi / 180)
   rhs_pulse <- matexp( Fx * 1i * angle * pi / 180)
   sys$rho <- lhs_pulse %*% sys$rho %*% rhs_pulse
   
-  # acquire
-  acquire(sys, detect = "1H")
-}
-
-#' Simple pulse and acquire sequence with ideal pulses.
-#' @param spin_params spin system definition.
-#' @param ft transmitter frequency in Hz.
-#' @param ref reference value for ppm scale.
-#' @return list of resonance amplitudes and frequencies.
-#' @export
-seq_pulse_acquire_31p <- function(spin_params, ft, ref) {
-  sys <- spin_sys(spin_params, ft, ref)
-  
-  sys$rho <- gen_F(sys, "z", "31P")
-   
-  angle <- 90
-  Fx <- gen_F(sys, "x", "31P")
-  lhs_pulse <- matexp(-Fx * 1i * angle * pi / 180)
-  rhs_pulse <- matexp( Fx * 1i * angle * pi / 180)
-  sys$rho <- lhs_pulse %*% sys$rho %*% rhs_pulse
+  if (acq_delay > 0) {
+    # apply delay
+    t <- acq_delay
+    # find the inverse of the eigenvector matrix
+    eig_vec_inv <- solve(sys$H_eig_vecs)
+    lhs <- sys$H_eig_vecs %*% diag(exp(sys$H_eig_vals * 2i * pi * t)) %*%
+      eig_vec_inv
+    rhs <- sys$H_eig_vecs %*% diag(exp(-sys$H_eig_vals * 2i * pi * t)) %*%
+      eig_vec_inv
+    sys$rho <- lhs %*% sys$rho %*% rhs
+  }
   
   # acquire
-  acquire(sys, detect = "31P")
+  acquire(sys, detect = nuc)
 }
 
 #' PRESS sequence with ideal pulses.
@@ -55,6 +50,7 @@ seq_press_ideal <- function(spin_params, ft, ref, TE1 = 0.01, TE2 = 0.02) {
   
   # apply delay
   t <- TE1 / 2
+  
   # find the inverse of the eigenvector matrix
   eig_vec_inv <- solve(sys$H_eig_vecs)
   lhs <- sys$H_eig_vecs %*% diag(exp(sys$H_eig_vals * 2i * pi * t)) %*%
@@ -103,16 +99,17 @@ seq_press_ideal <- function(spin_params, ft, ref, TE1 = 0.01, TE2 = 0.02) {
 #' @param spin_params spin system definition.
 #' @param ft transmitter frequency in Hz.
 #' @param ref reference value for ppm scale.
+#' @param nuc acquisition nucleus.
 #' @param TE echo time in seconds.
 #' @return list of resonance amplitudes and frequencies.
 #' @export
-seq_spin_echo_ideal <- function(spin_params, ft, ref, TE = 0.03) {
+seq_spin_echo_ideal <- function(spin_params, ft, ref, nuc = "1H", TE = 0.03) {
   sys <- spin_sys(spin_params, ft, ref)
   
   sys$rho <- gen_F(sys, "z")
    
   angle <- 90
-  Fx <- gen_F(sys, "x", "1H")
+  Fx <- gen_F(sys, "x", nuc)
   lhs_pulse <- matexp(-Fx * 1i * angle * pi / 180)
   rhs_pulse <- matexp( Fx * 1i * angle * pi / 180)
   sys$rho <- lhs_pulse %*% sys$rho %*% rhs_pulse
@@ -131,7 +128,7 @@ seq_spin_echo_ideal <- function(spin_params, ft, ref, TE = 0.03) {
   
   # apply pulse
   angle <- 180
-  Fy <- gen_F(sys, "y", "1H")
+  Fy <- gen_F(sys, "y", nuc)
   lhs_pulse <- matexp(-Fy * 1i * angle * pi / 180)
   rhs_pulse <- matexp( Fy * 1i * angle * pi / 180)
   sys$rho <- lhs_pulse %*% sys$rho %*% rhs_pulse
@@ -140,51 +137,7 @@ seq_spin_echo_ideal <- function(spin_params, ft, ref, TE = 0.03) {
   sys$rho <- lhs %*% sys$rho %*% rhs
   
   # acquire
-  acquire(sys, detect = "1H")
-}
-
-#' Spin echo sequence with ideal pulses.
-#' @param spin_params spin system definition.
-#' @param ft transmitter frequency in Hz.
-#' @param ref reference value for ppm scale.
-#' @param TE echo time in seconds.
-#' @return list of resonance amplitudes and frequencies.
-#' @export
-seq_spin_echo_ideal_31p <- function(spin_params, ft, ref, TE = 0.03) {
-  sys <- spin_sys(spin_params, ft, ref)
-  
-  sys$rho <- gen_F(sys, "z")
-   
-  angle <- 90
-  Fx <- gen_F(sys, "x", "31P")
-  lhs_pulse <- matexp(-Fx * 1i * angle * pi / 180)
-  rhs_pulse <- matexp( Fx * 1i * angle * pi / 180)
-  sys$rho <- lhs_pulse %*% sys$rho %*% rhs_pulse
-  
-  # apply delay
-  t <- TE / 2
-  # find the inverse of the eigenvector matrix
-  eig_vec_inv <- solve(sys$H_eig_vecs)
-  lhs <- sys$H_eig_vecs %*% diag(exp(sys$H_eig_vals * 2i * pi * t)) %*% 
-         eig_vec_inv
-  
-  rhs <- sys$H_eig_vecs %*% diag(exp(-sys$H_eig_vals * 2i * pi * t)) %*%
-         eig_vec_inv
-  
-  sys$rho <- lhs %*% sys$rho %*% rhs
-  
-  # apply pulse
-  angle <- 180
-  Fy <- gen_F(sys, "y", "31P")
-  lhs_pulse <- matexp(-Fy * 1i * angle * pi / 180)
-  rhs_pulse <- matexp( Fy * 1i * angle * pi / 180)
-  sys$rho <- lhs_pulse %*% sys$rho %*% rhs_pulse
-  
-  # apply delay
-  sys$rho <- lhs %*% sys$rho %*% rhs
-  
-  # acquire
-  acquire(sys, detect = "31P")
+  acquire(sys, detect = nuc)
 }
 
 #' CPMG style sequence with ideal pulses.
@@ -546,7 +499,7 @@ seq_steam_ideal_young <- function(spin_params, ft, ref, TE = 0.03, TM = 0.02,
 #' @return list of resonance amplitudes and frequencies.
 #' @export
 seq_steam_ideal_cof <- function(spin_params, ft, ref, TE = 0.03, TM = 0.02,
-                                    amp_scale = 2) {
+                                amp_scale = 2) {
   
   sys <- spin_sys(spin_params, ft, ref)
   Fz  <- gen_F(sys, "z")
